@@ -40,7 +40,11 @@ ControlPanel::ControlPanel( MainWindow* aMainW, FMPanel* aLeftPanel, FMPanel* aR
     commandLayout->setContentsMargins( 2, 2, 2, 2 );
     commandLayout->setSpacing(1);
     cpButton = new QPushButton( "&Copy" );
+#if defined(QEFEM_MAEMO_DEV)
     rnButton = new QPushButton( "&Rename" );
+#else
+    rnButton = new QPushButton( "&Rn" );
+#endif
     delButton = new QPushButton( "&Del" );
     searchButton = new QPushButton( "&Find" );
 #if !defined(QEFEM_MAEMO_DEV)
@@ -461,6 +465,9 @@ void ControlPanel::disableButtons()
     mkdirButton->setDisabled( true );
     bookmarkButton->setDisabled( true );
     searchButton->setDisabled( true );
+#if defined(QEFEM_MAEMO_DEV)
+    openButton->setDisabled( true );
+#endif
 }
 
 void ControlPanel::enableButtons()
@@ -474,6 +481,9 @@ void ControlPanel::enableButtons()
     mkdirButton->setEnabled( true );
     bookmarkButton->setEnabled( true );
     searchButton->setEnabled( true );
+#if defined(QEFEM_MAEMO_DEV)
+    openButton->setEnabled( true );
+#endif
 }
 
 void ControlPanel::stopAnimation()
